@@ -27,17 +27,10 @@ pyAgrum includes :
 #*   Free Software Foundation, Inc.,                                       *
 #*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-__version__ = '0.20.2'
+__version__ = '0.22.0'
 __license__ = __doc__
 __project_url__ = 'http://agrum.org'
 
-# for python2's compatibility
-try:
-    FileNotFoundError
-except NameError:
-    FileNotFoundError = IOError
-## end for python2's compatibility
-
 import numpy as np
 from .deprecated import *
 
@@ -69,7 +62,7 @@ from .pyAgrum import getNestedParallelism, setNestedParallelism
 
 from .pyAgrum import VarType_Discretized,VarType_Labelized,VarType_Range
 
-from .pyAgrum import DefaultInLabel, DuplicateElement, DuplicateLabel, EmptyBSTree, EmptySet, GumException, FatalError, FormatNotFound, GraphError, IOError, IdError, InvalidArc, InvalidArgument, InvalidArgumentsNumber, InvalidDirectedCycle, InvalidEdge, InvalidNode, MissingValueInDatabase, MissingVariableInDatabase, NoChild, NoNeighbour, NoParent, NotFound, NullElement, OperationNotAllowed, OutOfBounds, OutOfLowerBound, OutOfUpperBound, ReferenceError, SizeError, SyntaxError, UndefinedElement, UndefinedIteratorKey, UndefinedIteratorValue, UnknownLabelInDatabase
+from .pyAgrum import DefaultInLabel, DuplicateElement, DuplicateLabel, GumException, FatalError, FormatNotFound, GraphError, IOError, InvalidArc, InvalidArgument, InvalidArgumentsNumber, InvalidDirectedCycle, InvalidEdge, InvalidNode, DatabaseError, MissingValueInDatabase, MissingVariableInDatabase, NoChild, NoNeighbour, NoParent, NotFound, NullElement, OperationNotAllowed, OutOfBounds, ArgumentError, SizeError, SyntaxError, UndefinedElement, UndefinedIteratorKey, UndefinedIteratorValue, UnknownLabelInDatabase, CPTError
 
 
 # selection of imports extracted from dir(pyAgrum)
@@ -111,7 +104,7 @@ __all__=[
 
   'VarType_Discretized', 'VarType_Labelized', 'VarType_Range',
 
-  'DefaultInLabel', 'DuplicateElement', 'DuplicateLabel', 'EmptyBSTree', 'EmptySet', 'GumException', 'FatalError', 'FormatNotFound', 'GraphError', 'IOError', 'IdError', 'InvalidArc', 'InvalidArgument', 'InvalidArgumentsNumber', 'InvalidDirectedCycle', 'InvalidEdge', 'InvalidNode', 'MissingValueInDatabase', 'MissingVariableInDatabase', 'NoChild', 'NoNeighbour', 'NoParent', 'NotFound', 'NullElement', 'OperationNotAllowed', 'OutOfBounds', 'OutOfLowerBound', 'OutOfUpperBound', 'ReferenceError', 'SizeError', 'SyntaxError', 'UndefinedElement', 'UndefinedIteratorKey', 'UndefinedIteratorValue', 'UnknownLabelInDatabase',
+  'DefaultInLabel', 'DuplicateElement', 'DuplicateLabel', 'GumException', 'FatalError', 'FormatNotFound', 'GraphError', 'IOError', 'InvalidArc', 'InvalidArgument', 'InvalidArgumentsNumber', 'InvalidDirectedCycle', 'InvalidEdge', 'InvalidNode', 'DatabaseError', 'MissingValueInDatabase', 'MissingVariableInDatabase', 'NoChild', 'NoNeighbour', 'NoParent', 'NotFound', 'NullElement', 'OperationNotAllowed', 'OutOfBounds', 'ArgumentError', 'SizeError', 'SyntaxError', 'UndefinedElement', 'UndefinedIteratorKey', 'UndefinedIteratorValue', 'UnknownLabelInDatabase',"CPTError",
 
   "config"
   ]
@@ -133,8 +126,8 @@ def about():
   about() for pyAgrum
 
   """
-  print("pyAgrum version {0}".format('0.20.2'))
-  print("(c) 2015-2020 Pierre-Henri Wuillemin, Christophe Gonzales, Lionel Torti")
+  print("pyAgrum 0.22.0")
+  print("(c) 2015-2021 Pierre-Henri Wuillemin, Christophe Gonzales")
   print("""
     This is free software; see the source code for copying conditions.
     There is ABSOLUTELY NO WARRANTY; not even for MERCHANTABILITY or
@@ -394,7 +387,7 @@ Create a Markov network with a modified dot-like syntax which specifies:
 Examples
 --------
 >>> import pyAgrum as gum
->>> bn=gum.fastMN('A-B[1,3]-C{yes|No};C-D[2,4]-E[1,2.5,3.9]',6)
+>>> bn=gum.fastMN('A--B[1,3]--C{yes|No};C--D[2,4]--E[1,2.5,3.9]',6)
 
 Parameters
 ----------
@@ -500,19 +493,15 @@ def generateCSV(bn, name_out, n, show_progress=False, with_labels=False, random_
 
   genere = BNDatabaseGenerator(bn)
   if show_progress:
-    from pyAgrum.lib._utils.progress_bar import ProgressBar
-    prog = ProgressBar(name_out + ' : ', 0, 100, 77, mode='static', char='#')
-    prog.display()
+    from tqdm import tqdm
+    pbar = tqdm(total=100,desc=name_out,bar_format='{desc}: {percentage:3.0f}%|{bar}|',ncols=60)
     listen = PythonDatabaseGeneratorListener(genere)
 
     def whenStep(x, y):
-      prog.increment_amount()
-      prog.display()
+      pbar.update(1)
 
     def whenStop(msg):
-      prog.update_amount(100)
-      prog.display()
-      print()
+      pbar.close()
 
     listen.setWhenProgress(whenStep)
     listen.setWhenStop(whenStop)
@@ -524,7 +513,7 @@ def generateCSV(bn, name_out, n, show_progress=False, with_labels=False, random_
   genere.toCSV(name_out, with_labels)
 
   if show_progress:
-    print("Log2-Likelihood : {}".format(ll))
+    print(f"Log2-Likelihood : {ll}")
 
   return ll
 
@@ -538,59 +527,7 @@ def log2(p):
 
   Returns
   -------
-    a gpyAgrumum.Potential
+    a pyAgrum.Potential
   """
   return Potential(p).log2()
 
-
-def forDarkTheme():
-  """ change the color for arcs and text in graphs to be more visible in dark theme
-  """
-  config["notebook", "default_arc_color"] = "#AAAAAA"
-
-
-def forLightTheme():
-  """ change the color for arcs and text in graphs to be more visible in light theme
-  """
-  config["notebook", "default_arc_color"] = "#202020"
-
-
-def getBlackInTheme():
-  """ return the color used for arc and text in graphs
-  """
-  return config["notebook", "default_arc_color"]
-
-
-####################
-# Private functions
-####################
-def _proba2rgb(p, cmap, withSpecialColor):
-  (r, g, b, _) = cmap(p)
-  r = "%02x" % int(r * 256)
-  g = "%02x" % int(g * 256)
-  b = "%02x" % int(b * 256)
-
-  if withSpecialColor:  # add special color for p=0 or p=1
-    if p == 0.0:
-      r, g, b = "FF", "33", "33"
-    elif p == 1.0:
-      r, g, b = "AA", "FF", "FF"
-
-  return r, g, b
-
-
-def _proba2color(p, cmap):
-  r, g, b = _proba2rgb(p, cmap, withSpecialColor=False)
-  return "#" + r + g + b
-
-
-def _proba2bgcolor(p, cmap):
-  r, g, b = _proba2rgb(p, cmap, withSpecialColor=True)
-  return "#" + r + g + b
-
-
-def _proba2fgcolor(p, cmap):
-  if max([eval("0x" + s[0]) for s in _proba2rgb(p, cmap, withSpecialColor=True)]) <= 12:
-    return "#FFFFFF"
-  else:
-    return "#000000"
